summaryrefslogtreecommitdiffstats
path: root/quanta/utility/tagaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/utility/tagaction.h')
-rw-r--r--quanta/utility/tagaction.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/quanta/utility/tagaction.h b/quanta/utility/tagaction.h
index 3a58f603..84e01465 100644
--- a/quanta/utility/tagaction.h
+++ b/quanta/utility/tagaction.h
@@ -25,7 +25,7 @@
#include <tqstring.h>
#include <tqdom.h>
-class KMainWindow;
+class TDEMainWindow;
class QuantaView;
class TDEProcess;
class TQDomElement;
@@ -44,7 +44,7 @@ class NodeSelection;
* Paulo Moura Guedes, moura@tdewebdev.org
*/
-class TagAction : public KToggleAction
+class TagAction : public TDEToggleAction
{
Q_OBJECT
@@ -52,10 +52,10 @@ class TagAction : public KToggleAction
public:
/**
* Create an insert from dom element.
* @param toggle If set to true, the class behaves like a KToggleAction;
* Else it behaves like a KAction. This avoids the multi-inheritance problem.
*/
- TagAction(TQDomElement *element, KMainWindow *parentMainWindow, bool toggle = false);
+ TagAction(TQDomElement *element, TDEMainWindow *parentMainWindow, bool toggle = false);
virtual ~TagAction();
TQDomElement data() const { return tag; }
@@ -94,7 +94,7 @@ public slots:
* We need this information in order to know if queued actions should be applied.
* It's public because it can be activated by other classes if there are any queued actions.
*/
- virtual bool slotActionActivated(KAction::ActivationReason reason, TQt::ButtonState state);
+ virtual bool slotActionActivated(TDEAction::ActivationReason reason, TQt::ButtonState state);
protected slots:
virtual void slotGetScriptOutput( TDEProcess *, char *buffer, int buflen );
@@ -127,7 +127,7 @@ private:
TQTimer* timer;
TQDomElement tag;
TQFile* m_file;
- KMainWindow *m_parentMainWindow;
+ TDEMainWindow *m_parentMainWindow;
TQString m_inputFileName;
TQStringList m_argsList;
uint m_killCount;
@@ -52,10 +52,10 @@ class TagAction : public KToggleAction
/**
* Create an insert from dom element.
- * @param toggle If set to true, the class behaves like a KToggleAction;
- * Else it behaves like a KAction. This avoids the multi-inheritance problem.
+ * @param toggle If set to true, the class behaves like a TDEToggleAction;
+ * Else it behaves like a TDEAction. This avoids the multi-inheritance problem.
*/